@@ -301,12 +301,11 @@ phase3.2 <- function(z, x, ...)
 			fromBayes <- 'fromBayes' %in% names(x)
 			if (!fromBayes)
 			{
-				cat('*** Warning: Covariance matrix not positive definite *** \n')
-				cat('*** Standard errors not reliable ***\n')
-				cat('The following is approximately a linear combination \n')
-				cat('for which the data carries no information:\n',
-					thetext,'\n')
-				cat('It is advisable to drop one or more of these effects.\n')
+				warning('*** Warning: Covariance matrix not positive definite *** \n')
+				message('*** Standard errors not reliable ***')
+				message('The following is approximately a linear combination ')
+				message('for which the data carries no information:\n', thetext)
+				message('It is advisable to drop one or more of these effects.')
 				if (any(z$fixed || any(z$newfixed)))
 				{
 					Report(c('(This may be unimportant, and related to the fact\n',
@@ -359,8 +358,6 @@ CalculateDerivative3<- function(z,x)
 			Report(c("Warning: diagonal element(s)", sub,
 					" of derivative matrix < 0\n"), cf)
 		}
-		if (x$dolby)
-		{
 			if (z$sf2.byIteration)
 			{
 				scores <- apply(z$ssc, c(1,3), sum)  # z$nit by z$pp matrix
@@ -382,6 +379,8 @@ CalculateDerivative3<- function(z,x)
 				if (is.na(z$regrCoef[i])){z$regrCoef[i] <- 0}
 				options(warn = oldwarn)
 			}
+		if (x$dolby)
+		{
 			estMeans <- estMeans - (z$regrCoef * colMeans(scores))
 		}
 		Report('Correlations between scores and statistics:\n', cf)
@@ -396,6 +395,16 @@ CalculateDerivative3<- function(z,x)
 	z$msf <- cov(z$sf)
 	z$dfra1 <- z$dfra
 	z$dfra <- dfra
+	if (x$simOnly)
+	{
+		dmsf <- diag(z$msf)
+		sem <- sqrt(dmsf/dim(z$sf)[1])
+		if ((x$dolby) & (!z$thetaFromFile))
+		{
+			sem <- sem*sqrt(1 - (z$regrCor)^2)
+		}
+		z$estMeans.sem <- sem
+	}
 	z
 }
 
@@ -589,6 +598,14 @@ doPhase1or3Iterations <- function(phase, z, x, zsmall, xsmall, nits, nits6=0,
 			}
 		}
 		## iteration proper
+
+		if (z$thetaFromFile)
+		{
+			if (nit <= dim(z$thetaValues)[1])
+			{
+				zsmall$theta <- z$thetaValues[nit,]
+			}
+		}
 		if (z$int == 1)
 		{
 			zz <- x$FRAN(zsmall, xsmall)
@@ -634,6 +651,10 @@ doPhase1or3Iterations <- function(phase, z, x, zsmall, xsmall, nits, nits6=0,
 			z$sims[[z$nit]] <- zz$sims
 			z$chain[[z$nit]] <- zz$chain
 			fra <- fra + z$targets
+			if (z$thetaFromFile)
+			{
+				z$thetaUsed[z$nit, ] <- zsmall$theta
+			}
 		}
 		else
 		{
@@ -651,6 +672,10 @@ doPhase1or3Iterations <- function(phase, z, x, zsmall, xsmall, nits, nits6=0,
 					z$sf2s <- z$sf2s + zz[[i]]$fra
 				}
 				z$sims[[z$nit + (i - 1)]] <- zz[[i]]$sims
+				if (z$thetaFromFile)
+				{
+					z$thetaUsed[z$nit + (i - 1), ] <- zsmall$theta
+				}
 			}
 			if (z$FinDiff.method)
 			{
