@@ -1,4 +1,5 @@
 #/******************************************************************************
+#/******************************************************************************
 # * SIENA: Simulation Investigation for Empirical Network Analysis
 # *
 # * Web: http://www.stats.ox.ac.uk/~snijders/siena
@@ -11,7 +12,7 @@
 includeEffects <- function(myeff, ..., include=TRUE, name=myeff$name[1],
 						   type="eval", interaction1="", interaction2="",
 						   fix=FALSE, test=FALSE,
-						   character=FALSE)
+						   character=FALSE, verbose=TRUE)
 {
 	if (!inherits(myeff, 'sienaEffects'))
 	{
@@ -63,19 +64,23 @@ includeEffects <- function(myeff, ..., include=TRUE, name=myeff$name[1],
 	{
 #		print.data.frame(myeff[use, c("name", "shortName", "type",
 #			"interaction1", "interaction2", "include")])
-		print.sienaEffects(myeff[use,])
+		if (verbose)
+		{
+			print.sienaEffects(myeff[use,], includeRandoms = 
+					any(myeff$random & (myeff$shortName != 'density')))
+		}
 	}
 	if (hasArg('initialValue'))
 	{
-		cat("Warning: argument 'initialValue' has no effect in includeEffects; use setEffect.\n")
+		warning("Warning: argument 'initialValue' has no effect in includeEffects; use setEffect.\n")
 	}
 	if (hasArg('parameter'))
 	{
-		cat("Warning: argument 'parameter' has no effect in includeEffects; use setEffect.\n")
+		warning("Warning: argument 'parameter' has no effect in includeEffects; use setEffect.\n")
 	}
 	if (hasArg('random'))
 	{
-		cat("Warning: argument 'random' has no effect in includeEffects; use setEffect.\n")
+		warning("Warning: argument 'random' has no effect in includeEffects; use setEffect.\n")
 	}
 	myeff
 }
@@ -83,7 +88,7 @@ includeEffects <- function(myeff, ..., include=TRUE, name=myeff$name[1],
 includeInteraction <- function(myeff, ...,
 				include=TRUE, name=myeff$name[1],
 				type="eval", interaction1=rep("", 3), interaction2=rep("", 3),
-				fix=FALSE, test=FALSE, parameter=0, random=FALSE,
+				fix=FALSE, test=FALSE, parameter=NULL, random=FALSE,
 				character=FALSE, verbose=TRUE)
 {
 	if (character)
@@ -233,7 +238,8 @@ includeInteraction <- function(myeff, ...,
 	}
 	if (verbose)
 	{
-		print.sienaEffects(myeff[intn,], includeRandoms = random)
+		print.sienaEffects(myeff[intn,], includeRandoms = 
+					any(myeff$random & (myeff$shortName != 'density')))
 	}
 	myeff
 }
@@ -246,7 +252,7 @@ setEffect <- function(myeff, shortName, parameter=NULL,
 					include=TRUE, name=myeff$name[1],
 					type="eval", interaction1="", interaction2="",
 					effect1=0, effect2=0, effect3=0,
-					period=1, group=1, character=FALSE)
+					period=1, group=1, character=FALSE, verbose=TRUE)
 {
 	if (!character)
 	{
@@ -298,6 +304,9 @@ setEffect <- function(myeff, shortName, parameter=NULL,
 	# print.data.frame(myeff[use, c("name", "shortName", "type", "interaction1",
 	# 		"interaction2", "include", "parm", "fix", "test",
 	# 		"initialValue", "timeDummy", "period", "group")])
-	print.sienaEffects(myeff[use,])
+	if (verbose)
+	{
+		print.sienaEffects(myeff[use,], includeRandoms = random)
+	}
 	myeff
 }
