@@ -12,17 +12,22 @@
 #ifndef ALLEFFECTS_H_
 #define ALLEFFECTS_H_
 
+#include "AlterCovariateActivityEffect.h"
 #include "AltersCovariateAvAltEffect.h"
 #include "AltersCovariateAverageEffect.h"
-#include "InAltersCovariateAverageEffect.h"
 #include "AltersCovariateAvSimEffect.h"
+#include "AltersCovariateMinimumEffect.h"
+#include "AltersCovariateMaximumEffect.h"
 #include "AltersCovariateTotSimEffect.h"
 #include "AltersDist2CovariateAverageEffect.h"
 #include "AltersInDist2CovariateAverageEffect.h"
 #include "AntiIsolateEffect.h"
 #include "AverageAlterEffect.h"
+#include "AverageAlterContinuousEffect.h"
 #include "AverageAlterDist2Effect.h"
 #include "AverageAlterInDist2Effect.h"
+#include "AverageGroupEffect.h"
+#include "AverageGroupEgoEffect.h"
 #include "AverageInAlterEffect.h"
 #include "AverageReciprocatedAlterEffect.h"
 #include "BalanceEffect.h"
@@ -50,30 +55,37 @@
 #include "DyadicCovariateAvAltEffect.h"
 #include "DyadicCovariateMainEffect.h"
 #include "DyadicCovariateReciprocityEffect.h"
+#include "FeedbackEffect.h"
 #include "FourCyclesEffect.h"
 #include "HigherCovariateEffect.h"
+#include "HomCovariateActivityEffect.h"
 #include "GwdspEffect.h"
 #include "IndegreeEffect.h"
 #include "IndegreeActivityEffect.h"
+#include "IndegreeContinuousEffect.h"
 #include "IndegreePopularityEffect.h"
-#include "RecipdegreeActivityEffect.h"
-#include "RecipdegreePopularityEffect.h"
+#include "InAltersCovariateAverageEffect.h"
 #include "InInDegreeAssortativityEffect.h"
 #include "InIsolateDegreeEffect.h"
 #include "InOutDegreeAssortativityEffect.h"
 #include "InStructuralEquivalenceEffect.h"
 #include "InteractionCovariateEffect.h"
+#include "InterceptEffect.h"
 #include "InverseOutdegreeEffect.h"
 #include "InverseSquaredOutdegreeEffect.h"
 #include "IsolateEffect.h"
 #include "IsolateNetEffect.h"
+#include "IsolateOutContinuousEffect.h"
 #include "IsolatePopEffect.h"
 #include "JumpCovariateTransitiveTripletsEffect.h"
 #include "LinearShapeEffect.h"
 #include "MainCovariateEffect.h"
+#include "MainCovariateContinuousEffect.h"
 #include "MaxAlterEffect.h"
+#include "MaxAlterContinuousEffect.h"
 #include "NetworkInteractionEffect.h"
 #include "OutdegreeEffect.h"
+#include "OutdegreeContinuousEffect.h"
 #include "OutdegreeActivityEffect.h"
 #include "OutdegreeActivitySqrtEffect.h"
 #include "OutdegreePopularityEffect.h"
@@ -84,15 +96,16 @@
 #include "RecipdegreeActivityEffect.h"
 #include "RecipdegreePopularityEffect.h"
 #include "ReciprocalDegreeBehaviorEffect.h"
+#include "ReciprocalDegreeContinuousEffect.h"
 #include "ReciprocatedSimilarityEffect.h"
 #include "ReciprocityEffect.h"
 #include "SameCovariateEffect.h"
 #include "SameCovariateActivityEffect.h"
 #include "SameCovariateFourCyclesEffect.h"
-#include "HomCovariateActivityEffect.h"
-#include "AlterCovariateActivityEffect.h"
+#include "SettingSizeEffect.h"
 #include "SameCovariateTransitiveTripletsEffect.h"
 #include "HomCovariateTransitiveTripletsEffect.h"
+#include "SameCovariateTransitiveReciprocatedTripletsEffect.h"
 #include "SimilarityEffect.h"
 #include "SimilarityWEffect.h"
 #include "SimilarityTransitiveTripletsEffect.h"
@@ -106,8 +119,8 @@
 #include "TransitiveTripletsEffect.h"
 #include "TruncatedOutdegreeEffect.h"
 #include "TruncatedOutdegreeEffect2.h"
+#include "WienerEffect.h"
 #include "WWXClosureEffect.h"
 #include "WXXClosureEffect.h"
 #include "XWXClosureEffect.h"
-
 #endif /*ALLEFFECTS_H_*/
