@@ -15,6 +15,7 @@
 #include "EffectFactory.h"
 #include "data/Data.h"
 #include "data/NetworkLongitudinalData.h"
+#include "data/ContinuousLongitudinalData.h"
 #include "model/EffectInfo.h"
 #include "model/effects/AllEffects.h"
 #include "model/effects/generic/GenericNetworkEffect.h"
@@ -67,11 +68,11 @@
 #include "model/tables/EgocentricConfigurationTable.h"
 #include "model/tables/NetworkCache.h"
 
+
 using namespace std;
 
 namespace siena
 {
-
 /**
  * Constructor.
  * @param[in] pData the data this factory will create effects for
@@ -81,7 +82,6 @@ EffectFactory::EffectFactory(const Data * pData)
 	this->lpData = pData;
 }
 
-
 /**
  * Creates and returns a concrete effect of the Effect class hierarchy
  * corresponding to the given generic effect descriptor.
@@ -91,6 +91,12 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	Effect * pEffect = 0;
 	string effectName = pEffectInfo->effectName();
 
+	// Defined so we can later on differentiate between effects for 
+	// continuous and discrete dependent behavior variables
+	string variableName = pEffectInfo->variableName();
+	ContinuousLongitudinalData * pContinuousData = 
+        dynamic_cast<ContinuousLongitudinalData *>(this->lpData->pContinuousData(variableName));
+	
 	// Handle the user-defined interaction effects first.
 
 	if (pEffectInfo->pEffectInfo1())
@@ -208,19 +214,27 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "inPop")
 	{
-		pEffect = new IndegreePopularityEffect(pEffectInfo, false);
+		pEffect = new IndegreePopularityEffect(pEffectInfo, false, false);
+	}
+	else if (effectName == "inPop.c")
+	{
+		pEffect = new IndegreePopularityEffect(pEffectInfo, false, true);
 	}
 	else if (effectName == "inPopSqrt")
 	{
-		pEffect = new IndegreePopularityEffect(pEffectInfo, true);
+		pEffect = new IndegreePopularityEffect(pEffectInfo, true, false);
 	}
 	else if (effectName == "outPop")
 	{
-		pEffect = new OutdegreePopularityEffect(pEffectInfo, false);
+		pEffect = new OutdegreePopularityEffect(pEffectInfo, false, false);
+	}
+	else if (effectName == "outPop.c")
+	{
+		pEffect = new OutdegreePopularityEffect(pEffectInfo, false, true);
 	}
 	else if (effectName == "outPopSqrt")
 	{
-		pEffect = new OutdegreePopularityEffect(pEffectInfo, true);
+		pEffect = new OutdegreePopularityEffect(pEffectInfo, true, false);
 	}
 	else if (effectName == "reciPop")
 	{
@@ -232,15 +246,23 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "inAct")
 	{
-		pEffect = new IndegreeActivityEffect(pEffectInfo, false);
+		pEffect = new IndegreeActivityEffect(pEffectInfo, false, false);
+	}
+	else if (effectName == "inAct.c")
+	{
+		pEffect = new IndegreeActivityEffect(pEffectInfo, false, true);
 	}
 	else if (effectName == "inActSqrt")
 	{
-		pEffect = new IndegreeActivityEffect(pEffectInfo, true);
+		pEffect = new IndegreeActivityEffect(pEffectInfo, true, false);
 	}
 	else if (effectName == "outAct")
 	{
-		pEffect = new OutdegreeActivityEffect(pEffectInfo);
+		pEffect = new OutdegreeActivityEffect(pEffectInfo, false);
+	}
+	else if (effectName == "outAct.c")
+	{
+		pEffect = new OutdegreeActivityEffect(pEffectInfo, true);
 	}
 	else if (effectName == "outActSqrt")
 	{
@@ -252,15 +274,27 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "degPlus")
 	{
-		pEffect = new BothDegreesEffect(pEffectInfo);
+		pEffect = new BothDegreesEffect(pEffectInfo, false);
+	}
+	else if (effectName == "degPlus.c")
+	{
+		pEffect = new BothDegreesEffect(pEffectInfo, true);
 	}
 	else if (effectName == "outTrunc")
 	{
-		pEffect = new TruncatedOutdegreeEffect(pEffectInfo);
+		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, true, false);
 	}
 	else if (effectName == "outTrunc2")
 	{
-		pEffect = new TruncatedOutdegreeEffect2(pEffectInfo);
+		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, true, false);
+	}
+	else if (effectName == "outMore")
+	{
+		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, false, false);
+	}
+	else if (effectName == "outIso")
+	{
+		pEffect = new TruncatedOutdegreeEffect(pEffectInfo, true, true);
 	}
 	else if (effectName == "outInv")
 	{
@@ -350,7 +384,10 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new CovariateEgoSquaredEffect(pEffectInfo);
 	}
-
+	else if (effectName == "egoX_sim")
+	{
+		pEffect = new CovariateEgoEffect(pEffectInfo, false, false, true);
+	}
 	else if (effectName == "egoPlusAltX")
 	{
 		pEffect = new CovariateDiffEffect(pEffectInfo, false, 0);
@@ -399,10 +436,18 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new CovariateSimilarityEffect(pEffectInfo, false);
 	}
+	else if (effectName == "simX_sim")
+	{
+		pEffect = new CovariateSimilarityEffect(pEffectInfo, false, true);
+	}
 	else if (effectName == "simRecipX")
 	{
 		pEffect = new CovariateSimilarityEffect(pEffectInfo, true);
 	}
+	else if (effectName == "simRecipX_sim")
+	{
+		pEffect = new CovariateSimilarityEffect(pEffectInfo, true, true);
+	}
 	else if (effectName == "simXTransTrip")
 	{
 		pEffect = new SimilarityTransitiveTripletsEffect(pEffectInfo, false);
@@ -427,6 +472,14 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new SameCovariateTransitiveTripletsEffect(pEffectInfo, false);
 	}
+	else if (effectName == "sameXTransRecTrip")
+	{
+		pEffect = new SameCovariateTransitiveReciprocatedTripletsEffect(pEffectInfo, true);
+	}
+	else if (effectName == "diffXTransRecTrip")
+	{
+		pEffect = new SameCovariateTransitiveReciprocatedTripletsEffect(pEffectInfo, false);
+	}
 	else if (effectName == "inPopX")
 	{
 		string networkName = pEffectInfo->variableName();
@@ -491,11 +544,11 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "sameXOutAct")
 	{
-		pEffect = new SameCovariateActivityEffect(pEffectInfo, true);
+		pEffect = new SameCovariateActivityEffect(pEffectInfo, true, false);
 	}
 	else if (effectName == "diffXOutAct")
 	{
-		pEffect = new SameCovariateActivityEffect(pEffectInfo, false);
+		pEffect = new SameCovariateActivityEffect(pEffectInfo, false, false);
 	}
 	else if (effectName == "homXOutAct")
 	{
@@ -505,6 +558,14 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new AlterCovariateActivityEffect(pEffectInfo);
 	}
+	else if (effectName == "sameXReciAct")
+	{
+		pEffect = new SameCovariateActivityEffect(pEffectInfo, true, true);
+	}
+	else if (effectName == "diffXReciAct")
+	{
+		pEffect = new SameCovariateActivityEffect(pEffectInfo, false, true);
+	}
 	else if (effectName == "homXTransTrip")
 	{
 		pEffect = new HomCovariateTransitiveTripletsEffect(pEffectInfo, false);
@@ -529,6 +590,10 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new SameCovariateFourCyclesEffect(pEffectInfo, true);
 	}
+	else if (effectName == "avGroupEgoX")
+	{
+		pEffect = new AverageGroupEgoEffect(pEffectInfo);
+	}
 	else if (effectName == "cycle4")
 	{
 		pEffect = new FourCyclesEffect(pEffectInfo, true);
@@ -548,7 +613,6 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		GwespFunction * pFunction =
 			new GwespFunction(pEffectInfo->variableName(),
 				mytable, pEffectInfo->internalEffectParameter());
-
  		pEffect = new GenericNetworkEffect(pEffectInfo,
 			pFunction);
 	}
@@ -1288,15 +1352,47 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "indeg")
 	{
+		if (pContinuousData)
+		{
+			pEffect = new IndegreeContinuousEffect(pEffectInfo, false);
+		}
+		else
+		{
 		pEffect = new IndegreeEffect(pEffectInfo);
 	}
+	}
+	else if (effectName == "indegSqrt")
+	{
+		if (pContinuousData)
+		{
+			pEffect = new IndegreeContinuousEffect(pEffectInfo, true);
+		}
+	}
 	else if (effectName == "outdeg")
 	{
+		if (pContinuousData)
+		{
+			pEffect = new OutdegreeContinuousEffect(pEffectInfo, false);
+		}
+		else
+		{
 		pEffect = new OutdegreeEffect(pEffectInfo);
 	}
+	}
+	else if (effectName == "outdegSqrt")
+	{
+		if (pContinuousData)
+		{
+			pEffect = new OutdegreeContinuousEffect(pEffectInfo, true);
+		}
+	}
 	else if (effectName == "isolate")
 	{
-		pEffect = new IsolateEffect(pEffectInfo);
+		pEffect = new IsolateEffect(pEffectInfo, true);
+	}
+	else if (effectName == "outIsolate")
+	{
+		pEffect = new IsolateEffect(pEffectInfo, false);
 	}
 	else if (effectName == "isolateNet")
 	{
@@ -1318,6 +1414,10 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new AntiIsolateEffect(pEffectInfo, false, 3);
 	}
+	else if (effectName == "isolateOut")
+	{
+		pEffect = new IsolateOutContinuousEffect(pEffectInfo);
+	}
 	else if (effectName == "isolatePop")
 	{
 		pEffect = new IsolatePopEffect(pEffectInfo, true);
@@ -1326,6 +1426,50 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		pEffect = new InIsolateDegreeEffect(pEffectInfo);
 	}
+	else if (effectName == "settingSizeAct")
+	{
+		pEffect = new SettingSizeEffect(pEffectInfo, false, false, false, false, false);
+	}
+	else if (effectName == "settingSizeActSqrt")
+	{
+		pEffect = new SettingSizeEffect(pEffectInfo, false, false, true, false, false);
+	}
+	else if (effectName == "settingSizeActLog")
+	{
+		pEffect = new SettingSizeEffect(pEffectInfo, false, true, false, false, false);
+	}
+	else if (effectName == "settingOppAct")
+	{
+		pEffect = new SettingSizeEffect(pEffectInfo, true, false, false, false, false);
+	}
+	else if (effectName == "settingOppActSqrt")
+	{
+		pEffect = new SettingSizeEffect(pEffectInfo, true, false, true, false, false);
+	}
+	else if (effectName == "settingOppActLog")
+	{
+		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, false, false);
+	}
+	else if (effectName == "settingLogCreationAct")
+	{
+		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, true, false);
+	}
+	else if (effectName == "settingOppActD")
+	{
+		pEffect = new SettingSizeEffect(pEffectInfo, true, false, false, false, true);
+	}
+	else if (effectName == "settingOppActSqrtD")
+	{
+		pEffect = new SettingSizeEffect(pEffectInfo, true, false, true, false, true);
+	}
+	else if (effectName == "settingOppActLogD")
+	{
+		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, false, true);
+	}
+	else if (effectName == "settingLogCreationActD")
+	{
+		pEffect = new SettingSizeEffect(pEffectInfo, true, true, false, true, true);
+	}	
 	else if (effectName == "avSimRecip")
 	{
 		pEffect = new ReciprocatedSimilarityEffect(pEffectInfo, true, false);
@@ -1356,8 +1500,19 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "avAlt")
 	{
+		if (pContinuousData)
+		{
+			pEffect = new AverageAlterContinuousEffect(pEffectInfo);
+		}
+		else
+		{	
 		pEffect = new AverageAlterEffect(pEffectInfo, true, false);
 	}
+	}
+	else if (effectName == "avGroup")
+	{
+		pEffect = new AverageGroupEffect(pEffectInfo);
+	}
 	else if (effectName == "totAlt")
 	{
 		pEffect = new AverageAlterEffect(pEffectInfo, false, false);
@@ -1380,12 +1535,26 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "maxAlt")
 	{
+		if (pContinuousData)
+		{
+			pEffect = new MaxAlterContinuousEffect(pEffectInfo, false);
+		}
+		else
+		{
 		pEffect = new MaxAlterEffect(pEffectInfo, false);
 	}
+	}
 	else if (effectName == "minAlt")
 	{
+		if (pContinuousData)
+		{
+			pEffect = new MaxAlterContinuousEffect(pEffectInfo, true);
+		}
+		else
+		{
 		pEffect = new MaxAlterEffect(pEffectInfo, true);
 	}
+	}
 	else if (effectName == "avInAlt")
 	{
 		pEffect = new AverageInAlterEffect(pEffectInfo, true);
@@ -1436,7 +1605,18 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "recipDeg")
 	{
+		if (pContinuousData)
+		{
+			pEffect = new ReciprocalDegreeContinuousEffect(pEffectInfo, true);
+		}
+		else
+		{
 		pEffect = new ReciprocalDegreeBehaviorEffect(pEffectInfo);
+		}
+	}
+	else if (effectName == "nonrecipDeg")
+	{
+		pEffect = new ReciprocalDegreeContinuousEffect(pEffectInfo, false);
 	}
 	else if (effectName == "FFDeg")
 	{
@@ -1472,13 +1652,15 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	}
 	else if (effectName == "effFrom")
 	{
+		if (pContinuousData)
+		{
+			pEffect = new MainCovariateContinuousEffect(pEffectInfo);
+		}
+		else
+		{
 		pEffect = new MainCovariateEffect(pEffectInfo);
+		}
 	}
-	// else if (effectName == "inflIntX")
-	// {
-	// 	pEffect = new InteractionCovariateEffect(pEffectInfo, false, false,
-	// 		false);
-	//}
 	else if (effectName == "avSimEgoX")
 	{
 		pEffect = new InteractionCovariateEffect(pEffectInfo, true, false, false, false);
@@ -1515,6 +1697,14 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 	{
 		throw domain_error("Effect AltsAvAlt renamed to avXAlt");
 	}
+	else if (effectName == "minXAlt")
+	{
+		pEffect = new AltersCovariateMinimumEffect(pEffectInfo);
+	}
+	else if (effectName == "maxXAlt")
+	{
+		pEffect = new AltersCovariateMaximumEffect(pEffectInfo);
+	}
 	else if (effectName == "avXAlt")
 	{
 		pEffect = new AltersCovariateAverageEffect(pEffectInfo,true);
@@ -1785,11 +1975,23 @@ Effect * EffectFactory::createEffect(const EffectInfo * pEffectInfo) const
 		pEffect = new GenericNetworkEffect(pEffectInfo,
 			pChangeFunction, pStatisticFunction);
 	}
+	else if (effectName == "intercept")
+	{
+		pEffect = new InterceptEffect(pEffectInfo);
+
+	}
+	else if (effectName == "feedback")
+	{
+		pEffect = new FeedbackEffect(pEffectInfo);
+	}
+	else if (effectName == "wiener")
+	{
+		pEffect = new WienerEffect(pEffectInfo);
+	}
 	else
 	{
 		throw domain_error("Unexpected effect name: " + effectName);
 	}
-
 	return pEffect;
 }
 
