@@ -13,8 +13,8 @@
 #include "network/OneModeNetwork.h"
 #include "data/NetworkLongitudinalData.h"
 #include "model/variables/NetworkVariable.h"
-
-using namespace std;
+#include "model/EffectInfo.h"
+#include "data/Data.h"
 
 namespace siena
 {
@@ -23,10 +23,35 @@ namespace siena
  * Constructor.
  */
 OutdegreeActivityEffect::OutdegreeActivityEffect(
-	const EffectInfo * pEffectInfo) : NetworkEffect(pEffectInfo)
+	const EffectInfo * pEffectInfo, bool centered): NetworkEffect(pEffectInfo)
 {
+	this->lcentered = centered;
+	this->lcentering = 0.0;
+	this->lvariableName = pEffectInfo->variableName();
 }
 
+/**
+ * Initializes this function.
+ * @param[in] pData the observed data
+ * @param[in] pState the current state of the dependent variables
+ * @param[in] period the period of interest
+ * @param[in] pCache the cache object to be used to speed up calculations
+ */
+void OutdegreeActivityEffect::initialize(const Data * pData,
+	State * pState,
+	int period,
+	Cache * pCache)
+{
+	NetworkEffect::initialize(pData, pState, period, pCache);
+	if (this->lcentered)
+	{
+		NetworkLongitudinalData * pNetworkData =
+				pData->pNetworkData(this->lvariableName);
+		this->lcentering = pNetworkData->averageOutDegree();
+	}
+}
+
+
 
 /**
  * Calculates the contribution of a tie flip to the given actor.
@@ -43,14 +68,14 @@ double OutdegreeActivityEffect::calculateContribution(int alter) const
 		// After a tie withdrawal, the new out-degree would be d-1, and
 		// the new effect statistic s_i'=(d-1)^2. The current statistic
 		// is s_i=d^2, so the change would be s_i-s_i' = 2d-1.
-		change = 2 * d - 1;
+		change = 2*d - 1 - this->lcentering;
 	}
 	else
 	{
 		// When introducing a new tie, the new out-degree would be d+1, and
 		// the new effect statistic s_i'=(d+1)^2. The current statistic
 		// is s_i=d^2, so the change would be s_i'-s_i = 2d+1.
-		change = 2 * d + 1;
+		change = 2*d + 1 - this->lcentering;
 	}
 
 	return change;
@@ -64,7 +89,7 @@ double OutdegreeActivityEffect::calculateContribution(int alter) const
  */
 double OutdegreeActivityEffect::tieStatistic(int alter)
 {
-	return this->pNetwork()->outDegree(this->ego());
+	return (this->pNetwork()->outDegree(this->ego()) - this->lcentering);
 }
 
 /**
@@ -78,7 +103,7 @@ double OutdegreeActivityEffect::endowmentStatistic(Network * pLostTieNetwork)
 	int n = pStart->n();
 	for (int i = 0; i < n; i++)
 	{
-		int outdeg = pStart->outDegree(i);
+		int outdeg = (pStart->outDegree(i) - this->lcentering);
 		statistic += outdeg * pLostTieNetwork->outDegree(i);
 	}
 	return statistic;
