@@ -57,14 +57,12 @@ void XWXClosureEffect::initialize(const Data * pData,
 	Cache * pCache)
 {
 	DyadicCovariateDependentNetworkEffect::initialize(pData,
-		pState,
-		period,
-		pCache);
+		pState, period, pCache);
 
 	delete[] this->ltwoPathSums;
 	delete[] this->linStarSums;
-	this->ltwoPathSums = new double[this->pNetwork()->n()];
-	this->linStarSums = new double[this->pNetwork()->n()];
+	this->ltwoPathSums = new double[this->pNetwork()->m()]; // was n() until March 2018
+	this->linStarSums = new double[this->pNetwork()->m()]; // was n() until March 2018
 }
 
 
@@ -86,14 +84,13 @@ void XWXClosureEffect::preprocessEgo(int ego)
  * sum_h x_{ih} w_{hj}.
  */
 void XWXClosureEffect::calculateTwoPathSums(int i,
-	const Network * pNetwork,
-	double * sums) const
+	const Network * pNetwork, double * sums) const
 {
-	int n = pNetwork->n();
+	int m = pNetwork->m(); // was n() until March 2018
 
 	// Initialize
 
-	for (int j = 0; j < n; j++)
+	for (int j = 0; j < m; j++)
 	{
 		sums[j] = 0;
 	}
@@ -129,11 +126,11 @@ void XWXClosureEffect::calculateInStarSums(int i,
 	const Network * pNetwork,
 	double * sums) const
 {
-	int n = pNetwork->n();
+	int m = pNetwork->m();// was n() until March 2018
 
 	// Initialize
 
-	for (int j = 0; j < n; j++)
+	for (int j = 0; j < m; j++)
 	{
 		sums[j] = 0;
 	}
