@@ -27,9 +27,7 @@ public:
 	virtual ~XWXClosureEffect();
 
 	virtual void initialize(const Data * pData,
-		State * pState,
-		int period,
-		Cache * pCache);
+		State * pState, int period, Cache * pCache);
 
 	virtual void preprocessEgo(int ego);
 	virtual double calculateContribution(int alter) const;
@@ -38,22 +36,19 @@ protected:
 	virtual double tieStatistic(int alter);
 
 private:
-	void calculateTwoPathSums(int i,
-		const Network * pNetwork,
+	void calculateTwoPathSums(int i, const Network * pNetwork,
 		double * sums) const;
-	void calculateInStarSums(int i,
-		const Network * pNetwork,
+	void calculateInStarSums(int i, const Network * pNetwork,
 		double * sums) const;
 
 	// For a fixed i, this variable stores the value of sum_h x_{ih} w_{hj} for
 	// each j.
-
 	double * ltwoPathSums;
 
 	// For a fixed i, this variable stores the value of sum_h x_{ih} w_{jh} for
 	// each j.
-
 	double * linStarSums;
+
 	// divide indicates whether there will be division by the indegree
 	bool ltp; // contribution from twopaths
 	bool linst; // contribution from instars
