@@ -11,11 +11,6 @@
 #ifndef ALTERPREDICATE_H_
 #define ALTERPREDICATE_H_
 
-// TODO Header files should not do 'using namespace'.  This might lead to
-// namespace conflicts which are very hard to resolve.  Removeing this breaks
-// almost all alterpredicate since the <alterpredicate>.cpp files depend on it.
-using namespace std;
-
 namespace siena {
 
 // ----------------------------------------------------------------------------
