@@ -37,7 +37,7 @@ class ConstantFunction: public AlterFunction
 {
 public:
 	ConstantFunction(double constant);
-	ConstantFunction(string variableName, ConstantType constantType);
+	ConstantFunction(std::string variableName, ConstantType constantType);
 
 	virtual void initialize(const Data * pData,
 		State * pState,
@@ -61,7 +61,7 @@ private:
 	// The name of the variable if the constant is to be read from the
 	// observed data of a dependent variable.
 
-	string lvariableName;
+	std::string lvariableName;
 
 	// The function to be applied on the constant
 	double (* lpFunction)(double);
