@@ -21,13 +21,13 @@ class CovariateDistance2EgoAltSimNetworkFunction: public
 	CovariateDistance2NetworkFunction
 {
 public:
-	CovariateDistance2EgoAltSimNetworkFunction(string networkName,
-		string covariateName, bool excludeMissing, bool incoming);
+	CovariateDistance2EgoAltSimNetworkFunction(std::string networkName,
+		std::string covariateName, bool excludeMissing, bool outgoing);
 	virtual double value(int alter);
 
 private:
 	bool lexcludeMissing;
-	bool lincoming;
+	bool loutgoing;
 };
 
 }
