@@ -27,14 +27,12 @@ class NetworkCache;
 class MixedNetworkAlterFunction: public AlterFunction
 {
 public:
-	MixedNetworkAlterFunction(string firstNetworkName,
-		string secondNetworkName);
+	MixedNetworkAlterFunction(std::string firstNetworkName,
+		std::string secondNetworkName);
 	virtual ~MixedNetworkAlterFunction();
 
 	virtual void initialize(const Data * pData,
-		State * pState,
-		int period,
-		Cache * pCache);
+		State * pState, int period, Cache * pCache);
 
 protected:
 	bool firstOutTieExists(int alter) const;
@@ -45,8 +43,8 @@ protected:
 	inline NetworkCache * pFirstNetworkCache() const;
 
 private:
-	string lfirstNetworkName;
-	string lsecondNetworkName;
+	std::string lfirstNetworkName;
+	std::string lsecondNetworkName;
 	const Network * lpFirstNetwork;
 	const Network * lpSecondNetwork;
 	TwoNetworkCache * lpTwoNetworkCache;
