@@ -20,13 +20,11 @@ namespace siena
 class SameCovariateMixedTwoPathFunction: public CovariateMixedNetworkAlterFunction
 {
 public:
-	SameCovariateMixedTwoPathFunction(string firstNetworkName,
-		string secondNetworkName, string covariateName, bool excludeMissing);
+	SameCovariateMixedTwoPathFunction(std::string firstNetworkName,
+		std::string secondNetworkName, std::string covariateName, bool excludeMissing);
 		
 	virtual void initialize(const Data * pData,
-		State * pState,
-		int period,
-		Cache * pCache);
+		State * pState, int period, Cache * pCache);
 
 	virtual double value(int alter);
 
