@@ -22,6 +22,7 @@
 #include "data/NetworkLongitudinalData.h"
 #include "data/OneModeNetworkLongitudinalData.h"
 #include "data/BehaviorLongitudinalData.h"
+#include "data/ContinuousLongitudinalData.h"
 #include "data/ChangingDyadicCovariate.h"
 #include "data/ConstantDyadicCovariate.h"
 #include "data/ChangingCovariate.h"
@@ -33,10 +34,15 @@
 #include "model/StatisticCalculator.h"
 #include "data/ActorSet.h"
 #include "model/EpochSimulation.h"
+#include "model/SdeSimulation.h"
 #include "model/variables/DependentVariable.h"
 #include "model/variables/BehaviorVariable.h"
 #include "model/variables/NetworkVariable.h"
 #include "model/ml/MLSimulation.h"
+#include "network/layers/PrimaryLayer.h"
+#include "network/TieIterator.h"
+#include "utils/Utils.h"
+
 
 using namespace std;
 using namespace siena;
@@ -301,7 +307,21 @@ void updateParameters(SEXP EFFECTSLIST, SEXP THETA, vector<Data *> *
 				 	}
 				}
 			}
+			else if (strcmp(effectType, "rate") == 0 &&
+					 strcmp(effectName, "scale") == 0)		
+			{
+				int period = INTEGER(VECTOR_ELT(EFFECTS, periodCol))[eff] - 1;
+				if (strcmp(setting, "") == 0)
+				{
+					pModel->basicScaleParameter(period, currentValue);
+				}
 			else
+			{
+					error("setting found for behavior variable %s", 
+						networkName);
+				}
+			}
+			else // no rate or scale effect
 			{
 				EffectInfo * pEffectInfo =
 					(EffectInfo *) R_ExternalPtrAddr(
@@ -387,15 +407,15 @@ void setupOneModeNetwork(SEXP ONEMODE,
  * Create all observations for a one mode Network
  *
  */
-void setupOneModeObservations(SEXP ONEMODES,
-			      OneModeNetworkLongitudinalData *
-                              pOneModeNetworkLongitudinalData)
-
+void setupOneModeObservations(const std::string& name, SEXP ONEMODES,
+		OneModeNetworkLongitudinalData * pOneModeNetworkLongitudinalData)
 {
 	int observations = length(ONEMODES);
 	if (observations != pOneModeNetworkLongitudinalData->observationCount())
 	{
-		error ("wrong number of observations in OneMode");
+		error(("wrong number of observations in: " + name + ": expected "
+				+ toString(pOneModeNetworkLongitudinalData->observationCount()) + " got "
+				+ toString(observations)).c_str());
 	}
 	SEXP uo;
 	PROTECT(uo = install("uponly"));
@@ -442,40 +462,90 @@ void setupOneModeGroup(SEXP ONEMODEGROUP, Data * pData)
 		SEXP averageInDegree = PROTECT(getAttrib(ONEMODES, avin));
 		SEXP avout = PROTECT(install("averageOutDegree"));
 		SEXP averageOutDegree = PROTECT(getAttrib(ONEMODES, avout));
-		SEXP sets = PROTECT(install("settings"));
-		SEXP Setting = getAttrib(ONEMODES, sets);
+
 		SEXP nm = PROTECT(install("name"));
 		SEXP name = getAttrib(ONEMODES, nm);
-		const ActorSet* myActorSet = pData->pActorSet(CHAR(STRING_ELT(actorSet, 0)));
-		OneModeNetworkLongitudinalData *  pOneModeNetworkLongitudinalData =
-			pData->createOneModeNetworkData(CHAR(STRING_ELT(name, 0)), myActorSet);
+		const ActorSet* pActorSet = pData->pActorSet(CHAR(STRING_ELT(actorSet, 0)));
+		const char* cname = CHAR(STRING_ELT(name, 0));
+		OneModeNetworkLongitudinalData *  pNetData = pData->createOneModeNetworkData(cname, pActorSet);
 
-		for (int j = 0; j < length(Setting); j++)
+		// parse settings
+		SEXP settingsSymbol = PROTECT(install("settingsinfo"));
+		SEXP settingsList = PROTECT(getAttrib(ONEMODES, settingsSymbol));
+		for (int j = 0; j < length(settingsList); j++)
 		{
-			const char * settingName = CHAR(STRING_ELT(Setting, j));
-			pOneModeNetworkLongitudinalData->addSettingName(settingName);
+			SEXP settingInfo = VECTOR_ELT(settingsList, j);
+			SEXP infoNames = getAttrib(settingInfo, R_NamesSymbol);
+			std::string id, type, covar, only;
+//			Rprintf("setting %d\n", j);
+			// parse key value list
+			for (int k = 0; k < length(settingInfo); k++) {
+				// Rprintf("key value %d\n", k);
+				const char* key = CHAR(STRING_ELT(infoNames, k));
+				const char* value = CHAR(STRING_ELT(VECTOR_ELT(settingInfo, k), 0));
+				// Rprintf("%s = %s\n", key, value);
+				if      (strcmp(key, "id") == 0)    id    = std::string(value);
+				else if (strcmp(key, "type") == 0)  type  = std::string(value);
+				else if (strcmp(key, "covar") == 0) covar = std::string(value);
+				else if (strcmp(key, "only") == 0)  only  = std::string(value);
+			}
+			// parse strings to C++ types
+			Permission_Type permType = Permission_Type::BOTH;
+			if      (only == "up")   permType = Permission_Type::UP;
+			else if (only == "down") permType = Permission_Type::DOWN;
+			// asserts
+			if (id.length() == 0) error("settings id should not be empty");
+			if (type.length() == 0) error("settings type should not be empty");
+			// add it
+			Rprintf("%s %s %s %s\n", id.c_str(), type.c_str(), covar.c_str(), only.c_str());
+			pNetData->addSettingName(id, type, covar, permType);
 		}
 
-		pOneModeNetworkLongitudinalData->symmetric(*(LOGICAL(symmetric)));
-		pOneModeNetworkLongitudinalData->balanceMean(*(REAL(balmean)));
-		pOneModeNetworkLongitudinalData->structuralMean(*(REAL(structmean)));
-		pOneModeNetworkLongitudinalData->
-			averageInDegree(*(REAL(averageInDegree)));
-		pOneModeNetworkLongitudinalData->
-			averageOutDegree(*(REAL(averageOutDegree)));
-		setupOneModeObservations(ONEMODES,
-				pOneModeNetworkLongitudinalData);
-		//	Rprintf("%f %f\n", pOneModeNetworkLongitudinalData->
-		//	averageInDegree(),  pOneModeNetworkLongitudinalData->
-		//	averageOutDegree());
+		// check first two setting types
+		if (pNetData->rSettingNames().size() == 1) {
+			error("if setting are present use universal and primary");
+		} else if (pNetData->rSettingNames().size() >= 2) {
+			if (pNetData->rSettingNames().at(0).getSettingType() != "universal")
+				error("first setting should be type=universal");
+			if (pNetData->rSettingNames().at(1).getSettingType() != "primary")
+				error("second setting should be type=primary");
+		}
 
-		// Once all network data has been stored, calculate some
-		// statistical properties of that data.
-		pOneModeNetworkLongitudinalData->calculateProperties();
-		//Rprintf("%f %f\n", pOneModeNetworkLongitudinalData->
-		//	averageInDegree(), pOneModeNetworkLongitudinalData->
-		//	averageOutDegree());
-		UNPROTECT(14);
+		pNetData->symmetric(*(LOGICAL(symmetric)));
+		pNetData->balanceMean(*(REAL(balmean)));
+		pNetData->structuralMean(*(REAL(structmean)));
+		pNetData->averageInDegree(*(REAL(averageInDegree)));
+		pNetData->averageOutDegree(*(REAL(averageOutDegree)));
+		setupOneModeObservations(cname, ONEMODES, pNetData);
+		// Once all network data has been stored, calculate some statistical
+		// properties of that data.
+		pNetData->calculateProperties();
+
+		// add the primary setting for each observation
+		if (pNetData->rSettingNames().size() >= 1) {
+			std::string settingName = "primary(" + std::string(cname) + ")";
+			OneModeNetworkLongitudinalData* pSettingNetwork =
+				pData->createOneModeSimNetworkData(settingName.c_str(), pActorSet);
+
+			// Copy the primary layer to the data objects.  Cannot simply use
+			// `setupOneModeObservations` (with an object from R) because that
+			// expects a different format.
+			for (int obs = 0; obs < pNetData->observationCount(); obs++) {
+				const Network& net = *pNetData->pNetwork(obs);
+				PrimaryLayer l;
+				l.onInitializationEvent(net);
+				for (TieIterator tie = l.pLayer()->ties(); tie.valid(); tie.next()) {
+					pSettingNetwork->tieValue(tie.ego(), tie.alter(), obs, 1);
+					// TODO ignore missing and structural?
+					pSettingNetwork->missing(tie.ego(), tie.alter(), obs, 0);
+					pSettingNetwork->structural(tie.ego(), tie.alter(), obs, 0);
+				}
+				l.onNetworkDisposeEvent(net);
+			}
+			pSettingNetwork->calculateProperties();
+		}
+
+		UNPROTECT(15);
 	}
 }
 
@@ -701,16 +771,105 @@ void setupBehaviorGroup(SEXP BEHGROUP, Data *pData)
 		SEXP name = getAttrib(VECTOR_ELT(VECTOR_ELT(BEHGROUP, behavior), 0),
 				nm);
 
-		const ActorSet * myActorSet = pData->pActorSet(CHAR(STRING_ELT(
+		const ActorSet * pActorSet = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
 		BehaviorLongitudinalData * pBehaviorData =
-			pData->createBehaviorData(CHAR(STRING_ELT(name, 0)), myActorSet);
+			pData->createBehaviorData(CHAR(STRING_ELT(name, 0)), pActorSet);
 		//	Rprintf("%x\n", pBehaviorData);
 		setupBehavior(VECTOR_ELT(BEHGROUP, behavior), pBehaviorData);
 		UNPROTECT(2);
 	}
 }
 
+/**
+ * Create all observations for a continuous dependent variable
+ *
+ */
+void setupContinuous(SEXP CONTINUOUS, ContinuousLongitudinalData * 
+	pContinuousData)
+{
+    int observations = ncols(VECTOR_ELT(CONTINUOUS, 0));
+
+    if (observations != pContinuousData->observationCount())
+    {
+		error ("wrong number of observations in Continuous");
+    }
+    int nActors = nrows(VECTOR_ELT(CONTINUOUS, 0));
+
+    if (nActors != pContinuousData->n())
+    {
+        error ("wrong number of actors");
+    }
+    double * start = REAL(VECTOR_ELT(CONTINUOUS, 0));
+	int * missing = LOGICAL(VECTOR_ELT(CONTINUOUS, 1));
+
+    for (int period = 0; period < observations; period++)
+    {
+        for (int actor = 0; actor < nActors; actor++)
+        {
+			pContinuousData->value(period, actor, *start++);
+			pContinuousData->missing(period, actor, *missing++);
+        }
+    }
+    SEXP uo;
+    PROTECT(uo = install("uponly"));
+    SEXP uponly = getAttrib(VECTOR_ELT(CONTINUOUS, 0), uo);
+    SEXP dow;
+    PROTECT(dow = install("downonly"));
+    SEXP downonly = getAttrib(VECTOR_ELT(CONTINUOUS,0), dow);
+    for (int period = 0; period < (observations - 1); period++)
+    {
+        pContinuousData->upOnly(period, LOGICAL(uponly)[period]);
+        pContinuousData->downOnly(period, LOGICAL(downonly)[period]);
+    }
+    SEXP sim;
+    PROTECT(sim = install("simMean"));
+    SEXP simMean = getAttrib(VECTOR_ELT(CONTINUOUS,0), sim);
+	pContinuousData->similarityMean(REAL(simMean)[0]);
+	SEXP sims;
+	PROTECT(sims = install("simMeans"));
+	SEXP simMeans = getAttrib(VECTOR_ELT(CONTINUOUS, 0), sims);
+	SEXP simNames;
+	PROTECT(simNames = getAttrib(simMeans, R_NamesSymbol));
+	int numberNetworks = length(simMeans);
+	for (int net = 0; net < numberNetworks; net++)
+	{
+		pContinuousData->similarityMeans(REAL(simMeans)[net],
+			CHAR(STRING_ELT(simNames, net)));
+	}
+
+    // Now that the values are set, calculate some important statistics
+	pContinuousData->calculateProperties();
+	UNPROTECT(5);
+}
+/**
+ * Create one group of Continuous dependent variables
+ *
+ */
+void setupContinuousGroup(SEXP CONTGROUP, Data *pData)
+{
+    int nCont = length(CONTGROUP);
+
+    for (int continuous = 0; continuous < nCont; continuous++)
+    {
+		SEXP as;
+		PROTECT(as = install("nodeSet"));
+        SEXP actorSet = getAttrib(VECTOR_ELT(VECTOR_ELT(CONTGROUP, continuous), 0),
+								  as);
+
+        SEXP nm;
+        PROTECT(nm = install("name"));
+        SEXP name = getAttrib(VECTOR_ELT(VECTOR_ELT(CONTGROUP, continuous), 0),
+							  nm);
+
+        const ActorSet * myActorSet = pData->pActorSet(CHAR(STRING_ELT(
+                                                                actorSet, 0)));
+		ContinuousLongitudinalData * pContinuousData =
+			pData->createContinuousData(CHAR(STRING_ELT(name, 0)), myActorSet);
+		setupContinuous(VECTOR_ELT(CONTGROUP, continuous), pContinuousData);
+        UNPROTECT(2);
+    }
+}
 /**
  * Create a constant covariate
  *
@@ -793,18 +952,18 @@ void setupConstantCovariateGroup(SEXP COCOVARGROUP, Data *pData)
 		SEXP nm;
 		PROTECT(nm = install("name"));
 		SEXP name = getAttrib(VECTOR_ELT(COCOVARGROUP, constantCovariate), nm);
-		const ActorSet * myActorSet = pData->pActorSet(CHAR(STRING_ELT(
+		const ActorSet * pActorSet = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
 		int nActors = length(VECTOR_ELT(COCOVARGROUP, constantCovariate));
 		//    Rprintf("nactors %d\n", nActors);
 
-		if (nActors != myActorSet->n())
+		if (nActors != pActorSet->n())
 		{
 			error ("wrong number of actors");
 		}
 		ConstantCovariate * pConstantCovariate =
 			pData->createConstantCovariate(CHAR(STRING_ELT(name, 0)),
-					myActorSet);
+					pActorSet);
 		setupConstantCovariate(VECTOR_ELT(COCOVARGROUP,	constantCovariate),
 				pConstantCovariate);
 		SEXP mn;
@@ -948,17 +1107,17 @@ void setupChangingCovariateGroup(SEXP VARCOVARGROUP, Data *pData)
 		PROTECT(nm = install("name"));
 		SEXP name = getAttrib(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				nm);
-		const ActorSet * myActorSet = pData->pActorSet(CHAR(STRING_ELT(
+		const ActorSet * pActorSet = pData->pActorSet(CHAR(STRING_ELT(
 						actorSet, 0)));
 		int nActors = nrows(VECTOR_ELT(VARCOVARGROUP,changingCovariate));
 
-		if (nActors != myActorSet->n())
+		if (nActors != pActorSet->n())
 		{
 			error ("wrong number of actors");
 		}
 		ChangingCovariate * pChangingCovariate =
 			pData->createChangingCovariate(CHAR(STRING_ELT(name, 0)),
-					myActorSet);
+					pActorSet);
 		setupChangingCovariate(VECTOR_ELT(VARCOVARGROUP, changingCovariate),
 				pChangingCovariate);
 		SEXP mn;
@@ -1195,17 +1354,17 @@ void setupExogenousEventSet(SEXP EXOGEVENTSET, Data *pData)
 	//Rprintf("actor %d\n",*actor);
 	double * time = REAL(VECTOR_ELT(EVENTS, 3));
 	//Rprintf("time %5.4f\n",*time);
-	const ActorSet * myActorSet = pData->pActorSet(CHAR(STRING_ELT(actorSet,
+	const ActorSet * pActorSet = pData->pActorSet(CHAR(STRING_ELT(actorSet,
 					0)));
 	for (int event = 0; event < nEvents; event++)
 	{
 		if (*type == 1)
 		{
-			pData->addJoiningEvent(*period-1, myActorSet, *actor-1, *time);
+			pData->addJoiningEvent(*period-1, pActorSet, *actor-1, *time);
 		}
 		else
 		{
-			pData->addLeavingEvent(*period-1, myActorSet, *actor-1, *time);
+			pData->addLeavingEvent(*period-1, pActorSet, *actor-1, *time);
 		}
 		type++;
 		period++;
@@ -1223,13 +1382,13 @@ void setupExogenousEventSet(SEXP EXOGEVENTSET, Data *pData)
 
 	/* this is a matrix with column for each observation and row per actor*/
 
-	int nActors = myActorSet->n();
+	int nActors = pActorSet->n();
 	int *active = LOGICAL(ACTIVES);
 	for (int period = 0; period < pData->observationCount(); period++)
 	{
 		for (int actor = 0; actor < nActors; actor++)
 		{
-			pData->active(myActorSet, actor, period, *active);
+			pData->active(pActorSet, actor, period, *active);
 			active++;
 		}
 
@@ -1338,8 +1497,20 @@ SEXP createEffects(SEXP EFFECTS, Model *pModel, vector<Data *> * pGroupData,
 				}
 			}
 		}
-
+		else if (strcmp(effectType, "rate") == 0 &&
+				 strcmp(effectName, "scale") == 0)		
+		{
+			int period = INTEGER(VECTOR_ELT(EFFECTS, periodCol))[i] - 1;
+			if (strcmp(setting, "") == 0)
+			{
+				pModel->basicScaleParameter(period, initialValue);
+			}
 		else
+		{
+				error("setting found for variable %s", networkName);
+			}
+		}
+		else // no rate or scale effect
 		{
 			pEffectInfo = pModel->addEffect(networkName,
 					effectName,
@@ -1611,7 +1782,8 @@ void getStatistics(SEXP EFFECTSLIST,
 			//	Rprintf("%s %s \n", effectType, netType);
 			if (strcmp(effectType, "rate") == 0)
 			{
-				if (strcmp(effectName, "Rate") == 0)
+				if (strcmp(effectName, "Rate") == 0 ||
+					strcmp(effectName, "scale") == 0)
 				{
 					int groupno =
 						INTEGER(VECTOR_ELT(EFFECTS, groupCol))[i];
@@ -1638,6 +1810,20 @@ void getStatistics(SEXP EFFECTSLIST,
 								score = 0;
 							}
 						}
+						else if (strcmp(netType, "continuous") == 0)
+						{
+							statistic = pCalculator->totalDistance(period);
+
+							if (pEpochSimulation)
+							{
+								score = pEpochSimulation->pSdeSimulation()->basicScaleScore();
+								// Rprintf("The tau score gets update with %f\n", score); NYNKE
+							}
+							else
+							{
+								score = 0;
+							}
+						}
 						else
 						{
 							if (strcmp(setting, "") == 0)
