@@ -383,31 +383,9 @@ SEXP forwardModel(SEXP DERIV, SEXP DATAPTR, SEXP SEEDS,
 					pEpochSimulation->rVariables();
 				for (unsigned i = 0; i < rVariables.size(); i++)
 				{
-					NetworkVariable * pNetworkVariable =
-						dynamic_cast<NetworkVariable *>(rVariables[i]);
-					BehaviorVariable * pBehaviorVariable =
-						dynamic_cast<BehaviorVariable *>(rVariables[i]);
-
-					if (pNetworkVariable)
-					{
-						const Network * pNetwork =
-							pNetworkVariable->pNetwork();
-						SEXP thisEdge = getEdgeList(*pNetwork);
-						SET_VECTOR_ELT(VECTOR_ELT(VECTOR_ELT(sims, group), i),
-								period, thisEdge);
-					}
-					else if (pBehaviorVariable)
-					{
-						SEXP theseValues =
-							getBehaviorValues(*pBehaviorVariable);
-						SET_VECTOR_ELT(VECTOR_ELT(VECTOR_ELT(sims,
-										group), i), period, theseValues);
-					}
-					else
-					{
-						throw domain_error(
-							"Unexpected class of dependent variable");
-					}
+					// Rprintf("attach var %d (2)\n", i);
+					SET_VECTOR_ELT(VECTOR_ELT(VECTOR_ELT(sims, group), i), period,
+							var_to_sexp(rVariables[i]));
 				}
 			}
 			if (returnChains)
@@ -638,44 +616,19 @@ SEXP mlPeriod(SEXP DERIV, SEXP DATAPTR, SEXP MODELPTR, SEXP EFFECTSLIST,
 	}
 
 	/* sims will be the returned chain */
-	SEXP sims;
-	PROTECT(sims = allocVector(VECSXP, 1));
+	SEXP sims = PROTECT(allocVector(VECSXP, 1));
 	/* theseDeps will be the returned dependent variables */
-	SEXP theseDeps;
-	PROTECT(theseDeps = allocVector(VECSXP, numberVariables));
+	SEXP theseDeps = PROTECT(allocVector(VECSXP, numberVariables));
 	int nProtects = 5;
 
 	if (returnDeps)
 	{
 		// get simulated last state
 		pMLSimulation->gotoLastState();
-		const vector<DependentVariable *> lastVariables =
-				  pMLSimulation->rVariables();
-
+		const vector<DependentVariable *> rVariables = pMLSimulation->rVariables();
 		for (unsigned i = 0; i < numberVariables; i++)
 		{
-			NetworkVariable * pNetworkVariable =
-				dynamic_cast<NetworkVariable *>(lastVariables[i]);
-			BehaviorVariable * pBehaviorVariable =
-				dynamic_cast<BehaviorVariable *>(lastVariables[i]);
-				if (pNetworkVariable)
-			{
-				const Network * pNetwork = pNetworkVariable->pNetwork();
-				SEXP thisEdge;
-				PROTECT(thisEdge = getEdgeList(*pNetwork));
-				SET_VECTOR_ELT(theseDeps, i, thisEdge);
-			}
-			else if (pBehaviorVariable)
-			{
-				SEXP theseValues;
-				PROTECT(theseValues = getBehaviorValues(*pBehaviorVariable));
-				SET_VECTOR_ELT(theseDeps, i, theseValues);
-			}
-			else
-			{
-				throw domain_error("Unexpected class of dependent variable");
-			}
-		nProtects++;
+			SET_VECTOR_ELT(theseDeps, i, var_to_sexp(rVariables[i]));
 		}
 	}
 
@@ -810,127 +763,5 @@ SEXP clearStoredChains(SEXP MODELPTR, SEXP KEEP, SEXP GROUPPERIOD)
 }
 
 
-/** Recalculates the probabilities for a stored chain
- * corresponding to a specific group and period and
- * (negative) index. (index 1 is final).
- */
-SEXP getChainProbabilities(SEXP DATAPTR, SEXP MODELPTR,
-	SEXP GROUP, SEXP PERIOD, SEXP INDEX, SEXP EFFECTSLIST, SEXP THETA,
-	SEXP GETSCORES)
-{
-	/* need to make sure the parameters have been updated first */
-
-	/* get hold of the data vector */
-	vector<Data *> * pGroupData = (vector<Data *> *)
-		R_ExternalPtrAddr(DATAPTR);
-
-	int group = asInteger(GROUP) - 1;
-	int period = asInteger(PERIOD) - 1;
-	int groupPeriod = periodFromStart(*pGroupData, group, period);
-	Data * pData = (*pGroupData)[group];
-	/* get hold of the model object */
-	Model * pModel = (Model *) R_ExternalPtrAddr(MODELPTR);
-
-	/* update the parameters */
-	updateParameters(EFFECTSLIST, THETA, pGroupData, pModel);
-
-	/* create the ML simulation object */
-	MLSimulation * pMLSimulation = new MLSimulation(pData, pModel);
-
-	pMLSimulation->simpleRates(pModel->simpleRates());
-
-	// get chain for this period from model
-	int index = pModel->rChainStore(groupPeriod).size() - asInteger(INDEX);
-	//Rprintf(" %d \n",pModel->rChainStore(groupPeriod).size());
-	if (index < 0)
-	{
-		error("index invalid");
-	}
-	Chain * pChain = pModel->rChainStore(groupPeriod)[index];
-	// then copy the chain to the MLSimulation object. (deleting new one first)
-	pMLSimulation->pChain(pChain->copyChain());
-
-	int needScores = asInteger(GETSCORES);
-	int deriv = 0;
-	pModel->needScores(needScores);
-	pModel->needDerivatives(deriv);
-
-	/* set the number of steps to zero */
-	pModel->numberMLSteps(0);
-
-	/* run the epoch simulation for this period (do initialization) */
-	pMLSimulation->runEpoch(period);
-
-	SEXP ans;
-	PROTECT(ans = allocVector(VECSXP, 3));
-
-	double loglik = pMLSimulation->calculateLikelihood();
-
-	SET_VECTOR_ELT(ans, 0, ScalarReal(loglik));
-
-	if (needScores)
-	{
-		int dim = 0;
-		for (int i = 0; i < length(EFFECTSLIST); i++)
-		{
-			dim += length(VECTOR_ELT(VECTOR_ELT(EFFECTSLIST, i), 0));
-		}
-
-		/* fra will contain the scores and must be initialised
-		   to 0. Use rfra to reduce function evaluations. */
-		SEXP fra;
-		double * rfra;
-		PROTECT(fra = allocVector(REALSXP, dim));
-		rfra = REAL(fra);
-		for (int i = 0; i < length(fra); i++)
-		{
-			rfra[i] = 0;
-		}
-
-		/* dff will hold the return values of the derivatives */
-		SEXP dff;
-		double *rdff;
-		if (deriv)
-		{
-			PROTECT(dff = allocVector(REALSXP, dim * dim));
-			rdff = REAL(dff);
-			for (int i = 0; i < length(dff); i++)
-			{
-				rdff[i] = 0.0;
-			}
-		}
-
-		/* collect the scores and derivatives */
-		vector<double> derivs(dim * dim);
-		vector<double> score(dim);
-		getScores(EFFECTSLIST, 	period, group, pMLSimulation,
-			&derivs, &score);
-		/* fill up vectors for  return value list */
-		for (unsigned effectNo = 0; effectNo < score.size();
-			 effectNo++)
-		{
-			rfra[effectNo] = score[effectNo];
-		}
-		if (deriv)
-		{
-			for (unsigned ii = 0; ii < derivs.size(); ii++)
-			{
-				rdff[ii] = derivs[ii];
-			}
-		}
-		SET_VECTOR_ELT(ans, 1, fra);
-		UNPROTECT(1);
-		if (deriv)
-		{
-			SET_VECTOR_ELT(ans, 2, dff);
-			UNPROTECT(1);
-		}
-	}
-
-	delete pMLSimulation;
-
-	UNPROTECT(1);
-	return  ans;
-}
 
 }
